Struct simd::u8x16
[−]
[src]
#[repr(simd)]pub struct u8x16(_, _, _, _, _, _, _, _, _, _, _, _, _, _, _, _);
A SIMD vector of 16 u8s.
Methods
impl u8x16[src]
pub const fn new(
x0: u8,
x1: u8,
x2: u8,
x3: u8,
x4: u8,
x5: u8,
x6: u8,
x7: u8,
x8: u8,
x9: u8,
x10: u8,
x11: u8,
x12: u8,
x13: u8,
x14: u8,
x15: u8
) -> u8x16[src]
x0: u8,
x1: u8,
x2: u8,
x3: u8,
x4: u8,
x5: u8,
x6: u8,
x7: u8,
x8: u8,
x9: u8,
x10: u8,
x11: u8,
x12: u8,
x13: u8,
x14: u8,
x15: u8
) -> u8x16
Create a new instance.
pub const fn splat(x: u8) -> u8x16[src]
Create a new instance where every lane has value x.
pub fn eq(self, other: Self) -> bool8ix16[src]
Compare for equality.
pub fn ne(self, other: Self) -> bool8ix16[src]
Compare for equality.
pub fn lt(self, other: Self) -> bool8ix16[src]
Compare for equality.
pub fn le(self, other: Self) -> bool8ix16[src]
Compare for equality.
pub fn gt(self, other: Self) -> bool8ix16[src]
Compare for equality.
pub fn ge(self, other: Self) -> bool8ix16[src]
Compare for equality.
pub fn extract(self, idx: u32) -> u8[src]
pub fn replace(self, idx: u32, elem: u8) -> Self[src]
Return a new vector where the idxth lane is replaced
by elem.
Panics
replace will panic if idx is out of bounds.
pub fn load(array: &[u8], idx: usize) -> Self[src]
Load a new value from the idxth position of array.
This is equivalent to the following, but is possibly more efficient:
Self::new(array[idx], array[idx + 1], ...)
Panics
load will panic if idx is out of bounds in
array, or if array[idx..] is too short.
pub fn store(self, array: &mut [u8], idx: usize)[src]
Store the elements of self to array, starting at
the idxth position.
This is equivalent to the following, but is possibly more efficient:
array[i] = self.extract(0); array[i + 1] = self.extract(1); // ...
Panics
store will panic if idx is out of bounds in
array, or if array[idx...] is too short.
impl u8x16[src]